summaryrefslogtreecommitdiff
path: root/indra/newview/llfloaterpreference.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llfloaterpreference.h')
-rw-r--r--indra/newview/llfloaterpreference.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/newview/llfloaterpreference.h b/indra/newview/llfloaterpreference.h
index b71f7c647b..10a416beb5 100644
--- a/indra/newview/llfloaterpreference.h
+++ b/indra/newview/llfloaterpreference.h
@@ -75,8 +75,8 @@ public:
// refresh all the graphics preferences menus
static void refreshEnabledGraphics();
- // translate user's busy response message according to current locale if message is default, otherwise do nothing
- static void initBusyResponse();
+ // translate user's do not disturb response message according to current locale if message is default, otherwise do nothing
+ static void initDoNotDisturbResponse();
void processProperties( void* pData, EAvatarProcessorType type );
void processProfileProperties(const LLAvatarData* pAvatarData );
@@ -93,9 +93,9 @@ protected:
void onLanguageChange();
void onNameTagOpacityChange(const LLSD& newvalue);
// set value of "BusyResponseChanged" in account settings depending on whether busy response
// string differs from default after user changes.
- void onBusyResponseChanged();
+ void onDoNotDisturbResponseChanged();
// if the custom settings box is clicked
void onChangeCustom();
void updateMeterText(LLUICtrl* ctrl);
@@ -93,9 +93,9 @@ protected:
void onLanguageChange();
void onNameTagOpacityChange(const LLSD& newvalue);
- // set value of "BusyResponseChanged" in account settings depending on whether busy response
+ // set value of "DoNotDisturbResponseChanged" in account settings depending on whether do not disturb response
// string differs from default after user changes.